@@ -32,7 +32,7 @@ async def maybe_prompt_for_node(cog: CogT, context: PyLavContext, nodes: list[No
             clear_buttons_after=True,
             starting_page=0,
             selector_text=_("Pick a node"),
-            original_author=context.author if not context.interaction else context.interaction.user,
+            original_author=context.interaction.user if context.interaction else context.author,
         )
 
         await node_picker.start(context)
