@@ -25,11 +25,6 @@ def recursive_merge(d1: dict, d2: dict) -> dict:
     the second's leaf overwrites the first's.
     """
     for k, v in d1.items():
-        if k in d2:
-            # this next check is the only difference!
-            if all(isinstance(e, MutableMapping) for e in (v, d2[k])):
-                d2[k] = recursive_merge(v, d2[k])
-            # we could further check types and merge as appropriate here.
-    d3 = d1.copy()
-    d3.update(d2)
-    return d3
+        if k in d2 and all(isinstance(e, MutableMapping) for e in (v, d2[k])):
+            d2[k] = recursive_merge(v, d2[k])
+    return d1 | d2
